package de.fhdw.wtf.common.ast;

import java.io.Serializable;

import de.fhdw.wtf.common.ast.visitor.DatabaseIDStateVisitor;
import de.fhdw.wtf.common.ast.visitor.DatabaseIDStateVisitorReturn;
import de.fhdw.wtf.common.ast.visitor.DatabaseIDStateVisitorReturnException;
import de.fhdw.wtf.common.exception.generation.NoTypeIdSetException;

/**
 * Interface for State-Pattern. {@link DatabaseIDState} can be {@link DatabaseIDSetState} or
 * {@link DatabaseIDNotSetState}.
 * 
 */
public interface DatabaseIDState extends Serializable {
	
	/**
	 * Accepts a visitor.
	 * 
	 * @param v
	 *            The Visitor to be accepted.
	 */
	void accept(DatabaseIDStateVisitor v);
	
	/**
	 * Accepts a visitor with dynamic return type.
	 * 
	 * @param v
	 *            The Visitor to be accepted.
	 * @param <X>
	 *            ReturnType
	 * @return X
	 */
	<X> X accept(DatabaseIDStateVisitorReturn<X> v);
	
	/**
	 * Accepts a visitor with dynamic return type and exception.
	 * 
	 * @param v
	 *            The Visitor to be accepted.
	 * @param <X>
	 *            ReturnType
	 * @param <Y>
	 *            ExceptionType
	 * @return X
	 * @throws Y
	 *             Exception
	 */
	<X, Y extends Exception> X accept(DatabaseIDStateVisitorReturnException<X, Y> v) throws Y;
	
	/**
	 * Returns the current Id of this object.
	 * 
	 * @return database id
	 * @throws NoTypeIdSetException
	 *             no type id has been set.
	 */
	long getId() throws NoTypeIdSetException;
	
}
