package de.fhdw.wtf.common.ast.visitor;

import de.fhdw.wtf.common.ast.Name;
import de.fhdw.wtf.common.ast.QualifiedName;
import de.fhdw.wtf.common.ast.UnqualifiedName;

/**
 * Visitor for {@link de.fhdw.wtf.common.ast.Name}. All methods of this interface are throwing a
 * {@link de.fhdw.wtf.common.exception.referencer.InvalidTypeReferenceException} .
 * 
 * @param <X>
 *            ExceptionType
 */
public interface NameVisitorReturnNameException<X extends Exception> {
	
	/**
	 * Handle-method for a {@link de.fhdw.wtf.common.ast.QualifiedName}.
	 * 
	 * @param qName
	 *            : QualifiedName.
	 * @return Name
	 * @throws X
	 *             X
	 */
	Name handleQualifiedName(QualifiedName qName) throws X;
	
	/**
	 * Handle-method for a {@link de.fhdw.wtf.common.ast.UnqualifiedName}.
	 * 
	 * @param unqName
	 *            : UnqualifiedName.
	 * @return Name
	 * @throws X
	 *             X
	 */
	Name handleUnqualifiedName(UnqualifiedName unqName) throws X;
}
