package de.fhdw.wtf.common.constants.parser;

/**
 * Contains exception messages for parser.
 */
public final class ExceptionConstants {
	
	/**
	 * The provided token does not match the GroupElement definition.
	 */
	public static final String NO_GROUP_ELEMENT_EXCEPTION_MESSAGE = createNotMatchConstant("GroupElement");
	
	/**
	 * The provided token does not match the Group definition.
	 */
	public static final String NO_GROUP_EXCEPTION_MESSAGE = createNotMatchConstant("Group");
	
	/**
	 * The provided token does not match the Identifier definition.
	 */
	public static final String NO_IDENTIFIER_EXCEPTION_MESSAGE = createNotMatchConstant("Identifier");
	
	/**
	 * The provided token is an invalid token.
	 */
	public static final String INVALID_TOKEN_EXCEPTION_MESSAGE = "The provided token is an invalid token: ";
	
	/**
	 * The given ClassModifier already added.
	 */
	public static final String CLASS_MODIFIER_ALREADY_ADDED_EXCEPTION = createAlreadyAddedConstant("ClassModifier");
	
	/**
	 * The given AttributeModifier already added.
	 */
	public static final String ATTRIBUTE_MODIFIER_ALREADY_ADDED_EXCEPTION =
			createAlreadyAddedConstant("AttributeModifier");
	
	/**
	 * The given OperationModifier already added.
	 */
	public static final String OPERATION_MODIFIER_ALREADY_ADDED_EXCEPTION =
			createAlreadyAddedConstant("OperationModifier");
	
	/**
	 * Expected '-', found.
	 */
	public static final String NO_HYPHEN_EXCEPTION_MESSAGE = "Expected '-', found: ";
	
	/**
	 * Expected '->', found.
	 */
	public static final String NO_ARROW_EXCEPTION_MESSAGE = "Expected '->', found: ";
	
	/**
	 * Expected '{', found.
	 */
	public static final String NO_BRACELEFT_EXCEPTION_MESSAGE = "Expected '{', found: ";
	
	/**
	 * Expected '}', found.
	 */
	public static final String NO_BRACERIGHT_EXCEPTION_MESSAGE = "Expected '}', found: ";
	
	/**
	 * Expected '*', found.
	 */
	public static final String NO_ASTERISK_EXCEPTION_MESSAGE = "Expected '*', found: ";
	
	/**
	 * Expected ';', found.
	 */
	public static final String NO_SEMICOLON_EXCEPTION_MESSAGE = "Expected ';', found: ";
	
	/**
	 * Expected '+', found.
	 */
	public static final String NO_PLUS_SYMBOL_EXCEPTION_MESSAGE = "Expected '+', found: ";
	
	/**
	 * Expected ':', found.
	 */
	public static final String NO_COLON_EXCEPTION_MESSAGE = "Expected ':', found: ";
	
	/**
	 * Expected '=', found.
	 */
	public static final String NO_EQUAL_EXCEPTION_MESSAGE = "Expected '=', found: ";
	
	/**
	 * Expected '[', found.
	 */
	public static final String NO_SQUARE_BRACKET_OPEN_EXCEPTION_MESSAGE = "Expected '[', found: ";
	
	/**
	 * Expected ']', found.
	 */
	public static final String NO_SQUARE_BRACKET_CLOSE_EXCEPTION_MESSAGE = "Expected ']', found: ";
	
	/**
	 * Expected ']]', found.
	 */
	public static final String NO_DOUBLE_SQUARE_BRACKET_CLOSE_EXCEPTION_MESSAGE = "Expected ']]', found: ";
	
	/**
	 * The provided token does not match the class modifier definition.
	 */
	public static final String NO_CLASS_MODIFIER_EXCEPTION_MESSAGE = createNotMatchConstant("class modifier");
	
	/**
	 * The provided token does not match the attribute modifier definition.
	 */
	public static final String NO_ATTRIBUTE_MODIFIER_EXCEPTION_MESSAGE = createNotMatchConstant("attribute modifier");
	
	/**
	 * Reached unexpected the end of the stream.
	 */
	public static final String SKIP_REACHED_END_TOKEN_EXCEPTION_MESSAGE = "Reached unexpected the end of the stream.";
	
	/**
	 * Expected '(', found.
	 */
	public static final String NO_BRACKET_OPEN_EXCEPTION_MESSAGE = "Expected '(', found: ";
	
	/**
	 * Expected ')', found.
	 */
	public static final String NO_BRACKET_CLOSE_EXCEPTION_MESSAGE = "Expected ')', found: ";
	
	/**
	 * Expected '|', found.
	 */
	public static final String NO_PIPE_SYMBOL_EXCEPTION_MESSAGE = "Expected '|', found: ";
	
	/**
	 * Expected TypeOccurrence, found nothing.
	 */
	public static final String NO_PRODUCT_OR_SUM_EXCEPTION_MESSAGE = "Expected TypeOccurrence, found nothing.";
	
	/**
	 * Expected '|' or '+', found.
	 */
	public static final String NO_PLUS_OR_PIPE_EXCEPTION_MESSAGE = "Expected '|' or '+', found: ";
	
	/**
	 * Expected ',', found.
	 */
	public static final String NO_COMMA_TOKEN_EXCEPTION_MESSAGE = "Expected ',', found: ";
	
	/**
	 * Expected '?', found.
	 */
	public static final String NO_QUESTIONMARK_TOKEN_EXCEPTION = "Expected '?', found: ";
	
	/**
	 * The provided token does not match the operation modifier definition.
	 */
	public static final String NO_OPERATION_MODIFIER_EXCEPTION_MESSAGE = createNotMatchConstant("operation modifier");
	
	/**
	 * Expected Type, found.
	 */
	public static final String NO_TYPE_EXCEPTION_MESSAGE = "Expected Type, found:  ";
	
	/**
	 * The parser found exceptions in the given token stream.
	 */
	public static final String NO_VALID_TOKEN_STREAM_EXCEPTION_MESSAGE = "The parser found exceptions"
			+ " in the given token stream.";
	
	/**
	 * The Sum contains Anything, so it is standardized Anything.
	 * 
	 */
	public static final String SUM_IS_ANYTHING_MESSAGE = "The Sum contains Anything, so it is standardized Anything.";
	
	/**
	 * Contains exception messages for parser.
	 */
	private ExceptionConstants() {
	}
	
	/**
	 * The provided token does not match the x definition: .
	 * 
	 * @param x
	 *            Fill the gap
	 * @return Constant
	 */
	private static String createNotMatchConstant(final String x) {
		return "The provided token does not match the " + x + " definition: ";
	}
	
	/**
	 * The given x already added: .
	 * 
	 * @param x
	 *            Fill the gap
	 * @return Constant
	 */
	private static String createAlreadyAddedConstant(final String x) {
		return "The given " + x + " already added: ";
	}
	
}
