package de.fhdw.wtf.common.exception.walker;

import de.fhdw.wtf.common.ast.Name;
import de.fhdw.wtf.common.exception.editor.EditorMarkable;
import de.fhdw.wtf.common.exception.editor.EditorMarker;
import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Will be thrown if the {@link de.fhdw.wtf.walker.tasks.BaseTypeInheritanceCheck} found a class witch extends a
 * Basetype.
 * 
 */
public final class BaseTypeInheritanceException extends TaskException implements EditorMarkable {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 3858521011605735153L;
	
	/**
	 * First-Token.
	 */
	private final Token firstToken;
	
	/**
	 * Last-Token.
	 */
	private final Token lastToken;
	
	/**
	 * Constructor of {@link BaseTypeInheritanceException}.
	 * 
	 * @param name
	 *            name of the class
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 */
	private BaseTypeInheritanceException(final Name name, final Token firstToken, final Token lastToken) {
		super(de.fhdw.wtf.common.constants.walker.ExceptionConstants.BASETYPE_INHERITANCE_MESSAGE + name);
		this.firstToken = firstToken;
		this.lastToken = lastToken;
	}
	
	/**
	 * Creates a {@link BaseTypeInheritanceException}-Object.
	 * 
	 * @param name
	 *            name of the class
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 * @return The {@link BaseTypeInheritanceException}-Object.
	 */
	public static BaseTypeInheritanceException create(final Name name, final Token firstToken, final Token lastToken) {
		return new BaseTypeInheritanceException(name, firstToken, lastToken);
	}
	
	@Override
	public Position getStartPosition() {
		return this.firstToken.getPosition();
	}
	
	@Override
	public String getDescription() {
		return this.getMessage();
	}
	
	@Override
	public Position getEndPos() {
		return this.lastToken.getPosition();
	}
	
	@Override
	public EditorMarker getMarker() {
		return EditorMarker.BASETYPE_INHERITANCE_MARKER;
	}
	
}
