package de.fhdw.wtf.common.task;

import java.util.Collection;
import java.util.concurrent.ExecutionException;

import de.fhdw.wtf.common.task.result.TaskResult;

public interface TaskExecutor {
	
	/**
	 * Submits a task for execution. This task is started when resources are available.
	 * 
	 * @param a
	 *            task that should be run
	 */
	void submit(DependencyTask a);
	
	/**
	 * Lets this task executor know about that task.
	 * 
	 * @param newTask
	 *            newly introduced task
	 * @see #startAllKnownTasks()
	 */
	void introduce(DependencyTask newTask);
	
	/**
	 * Starts all known dependency tasks that have no unmet dependencies.
	 * 
	 * @throws InterruptedException
	 *             InterruptedException
	 * @see #introduce(DependencyTask)
	 */
	void startAllKnownTasks() throws InterruptedException;
	
	/**
	 * Waits for the results of currently running tasks and returns them after completion. Blocks the calling thread
	 * until no new task is submitted in a running task.
	 * 
	 * @return results of execution
	 * @throws InterruptedException
	 *             InterruptedException
	 * @throws ExecutionException
	 *             ExecutionException
	 */
	Collection<TaskResult> getResultsAndShutdown() throws InterruptedException, ExecutionException;
	
}
