package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the "abstract"-modifier as a token in WTF.
 */
public final class AbstractToken extends ClassModifierToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 1183547882479606069L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 849783;
	
	/**
	 * Defines constant "abstract" for {@link AbstractToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "abstract";
	
	/**
	 * Private constructor for {@link AbstractToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the {@link ClassModifierToken} <abstract> in the original input.
	 */
	private AbstractToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link AbstractToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link ClassModifierToken} in the original input.
	 * @return a new instance of this {@link ClassModifierToken} token.
	 */
	public static AbstractToken create(final Position position) {
		return new AbstractToken(position);
	}
	
	@Override
	public boolean isAbstractModifierToken() {
		return true;
	}
	
	@Override
	public boolean isOperationModifierToken() {
		return true;
	}
	
	@Override
	public boolean isAbstractOperationToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isAbstractModifierToken();
	}
	
	@Override
	public String stringRepresentation() {
		return TEXTUAL_REPRESENTATION;
	}
	
	@Override
	public int getLength() {
		return AbstractToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
