package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the curly bracket close '}' symbol as a token.
 */
public final class CurlyBracketCloseToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -9209304214851954790L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 98234255;
	
	/**
	 * Private constructor for {@link CurlyBracketCloseToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol '}' in the original input.
	 */
	private CurlyBracketCloseToken(final Position position) {
		super(position, SymbolConstants.CURLYBRACKETCLOSE);
	}
	
	/**
	 * Factory method for {@link CurlyBracketCloseToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static CurlyBracketCloseToken create(final Position position) {
		return new CurlyBracketCloseToken(position);
	}
	
	@Override
	public boolean isCurlyBracketCloseToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isCurlyBracketCloseToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.CURLYBRACKETCLOSE;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
