package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the exclamation symbol '!' as a token.
 */
public final class ExclamationToken extends SymbolToken {
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 9836623;
	
	/**
	 * Creates a new ExclamationToken at the given position.
	 * 
	 * @param position
	 *            represents the start position of the symbol '!' in the original input
	 */
	private ExclamationToken(final Position position) {
		super(position, SymbolConstants.EXCLAMATION);
	}
	
	/**
	 * Creates a new ExclamationToken at the given position.
	 * 
	 * @param position
	 *            represents the start position of the symbol '!' in the original input
	 * @return a new instance of this {@link SymbolToken}
	 */
	public static ExclamationToken create(final Position position) {
		return new ExclamationToken(position);
	}
	
	@Override
	public boolean isExclamationToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isExclamationToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.EXCLAMATION;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
