package de.fhdw.wtf.parser;

import java.util.Collection;

import de.fhdw.wtf.common.ast.type.MapType;
import de.fhdw.wtf.common.ast.type.Type;
import de.fhdw.wtf.common.exception.parser.AbstractParserException;
import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.Token;

/**
 * Parser to parse the given TokenStream to {@link MapType}s.
 */
final class MapParser {
	
	/**
	 * TokenStream.
	 */
	private final TokenStream stream;
	
	/**
	 * Collection of exceptions.
	 */
	private final Collection<AbstractParserException> exceptions;
	
	/**
	 * Constructor of {@link MapParser}.
	 * 
	 * @param stream
	 *            tokenStream
	 * @param exceptions
	 *            collection of exceptions
	 */
	private MapParser(final TokenStream stream, final Collection<AbstractParserException> exceptions) {
		this.stream = stream;
		this.exceptions = exceptions;
	}
	
	/**
	 * FactoryMethod for {@link MapParser}.
	 * 
	 * @param stream
	 *            tokenStream
	 * @param exceptions
	 *            collection of exceptions
	 * @return The {@link MapParser}-Object.
	 */
	static MapParser create(final TokenStream stream, final Collection<AbstractParserException> exceptions) {
		return new MapParser(stream, exceptions);
	}
	
	/**
	 * Parses a TokenStream to a MapType.
	 * 
	 * @return Map
	 * @throws AbstractParserException
	 *             AbstractParserException
	 */
	MapType parse() throws AbstractParserException {
		final Token firstToken = this.stream.next();
		final Type key = TypeParser.create(this.stream, this.exceptions).parse();
		ParserUtils.requireAndRemoveArrowToken(this.stream);
		final Type value = TypeParser.create(this.stream, this.exceptions).parse();
		ParserUtils.requireAndRemoveSquareBracketCloseToken(this.stream);
		final MapType map = MapType.create(firstToken, key, value);
		map.setLastToken(value.getLastToken());
		return map;
	}
	
}
